pub struct StructField {
pub name: String,
pub ty: TypeRef,
pub doc: Option<String>,
pub default: Option<Value>,
}Fields
name: Stringty: TypeRefdoc: Option<String>default: Option<Value>Trait Implementations
Sourceimpl Clone for StructField
impl Clone for StructField
Sourcefn clone(&self) -> StructField
fn clone(&self) -> StructField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructField
impl Debug for StructField
Sourceimpl<'de> Deserialize<'de> for StructField
impl<'de> Deserialize<'de> for StructField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StructField
impl JsonSchema for StructField
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StructField
impl PartialEq for StructField
Sourcefn eq(&self, other: &StructField) -> bool
fn eq(&self, other: &StructField) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StructField
impl Serialize for StructField
impl StructuralPartialEq for StructField